@@ -60,6 +60,8 @@ LOG_COLUMNS = {'wavelength': [False, False, True],
                'v_95': [False, False, False],
                'chisqr': [False, False, False],
                'redchi': [False, False, False],
+               'aic':  [False, False, False],
+               'bic':  [False, False, False],
                'observation': [False, False, False],
                'comments': [False, False, False]}
 
@@ -75,8 +77,8 @@ LINELOG_TYPES = {'index': '<U50',
                  'pynebCode': '<f8',
                  'pynebLabel': '<f8',
                  'lineType': '<f8',
-                 'latexLabel': '<U50',
-                 'blended_label': '<U50',
+                 'latexLabel': '<U100',
+                 'blended_label': '<U120',
                  'w1': '<f8',
                  'w2': '<f8',
                  'w3': '<f8',
